==> plantuml-libs-9.0.0.tgz: package/distribution/aws-q2-2022/Resource/MachineLearning/AmazonSageMakerTrain.md <==
# AmazonSageMakerTrain


```text
aws-q2-2022/Resource/MachineLearning/AmazonSageMakerTrain
```

```text
include('aws-q2-2022/Resource/MachineLearning/AmazonSageMakerTrain')
```



| Illustration | AmazonSageMakerTrain | AmazonSageMakerTrainCard | AmazonSageMakerTrainGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q2-2022/Resource/MachineLearning/AmazonSageMakerTrain.png) | ![illustration for AmazonSageMakerTrain](../../../aws-q2-2022/Resource/MachineLearning/AmazonSageMakerTrain.Local.png) | ![illustration for AmazonSageMakerTrainCard](../../../aws-q2-2022/Resource/MachineLearning/AmazonSageMakerTrainCard.Local.png) | ![illustration for AmazonSageMakerTrainGroup](../../../aws-q2-2022/Resource/MachineLearning/AmazonSageMakerTrainGroup.Local.png) |




## AmazonSageMakerTrain

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AmazonSageMakerTrain
include('aws-q2-2022/Resource/MachineLearning/AmazonSageMakerTrain')

' renders the element
AmazonSageMakerTrain('AmazonSageMakerTrain', 'Amazon Sage Maker Train', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AmazonSageMakerTrain
include('aws-q2-2022/Resource/MachineLearning/AmazonSageMakerTrain')

' renders the element
AmazonSageMakerTrain('AmazonSageMakerTrain', 'Amazon Sage Maker Train', 'an optional tech label')
@enduml
```

## AmazonSageMakerTrainCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AmazonSageMakerTrainCard
include('aws-q2-2022/Resource/MachineLearning/AmazonSageMakerTrain')

' renders the element
AmazonSageMakerTrainCard('AmazonSageMakerTrainCard', 'Amazon Sage Maker Train Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AmazonSageMakerTrainCard
include('aws-q2-2022/Resource/MachineLearning/AmazonSageMakerTrain')

' renders the element
AmazonSageMakerTrainCard('AmazonSageMakerTrainCard', 'Amazon Sage Maker Train Card', 'an optional description')
@enduml
```

## AmazonSageMakerTrainGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AmazonSageMakerTrainGroup
include('aws-q2-2022/Resource/MachineLearning/AmazonSageMakerTrain')

' renders the element
AmazonSageMakerTrainGroup('AmazonSageMakerTrainGroup', 'Amazon Sage Maker Train Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AmazonSageMakerTrainGroup
include('aws-q2-2022/Resource/MachineLearning/AmazonSageMakerTrain')

' renders the element
AmazonSageMakerTrainGroup('AmazonSageMakerTrainGroup', 'Amazon Sage Maker Train Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-9.1.0.tgz: package/distribution/aws-q1-2022/Resource/MachineLearning/AmazonSageMakerTrain.md <==
# AmazonSageMakerTrain


```text
aws-q1-2022/Resource/MachineLearning/AmazonSageMakerTrain
```

```text
include('aws-q1-2022/Resource/MachineLearning/AmazonSageMakerTrain')
```



| Illustration | AmazonSageMakerTrain | AmazonSageMakerTrainCard | AmazonSageMakerTrainGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q1-2022/Resource/MachineLearning/AmazonSageMakerTrain.png) | ![illustration for AmazonSageMakerTrain](../../../aws-q1-2022/Resource/MachineLearning/AmazonSageMakerTrain.Local.png) | ![illustration for AmazonSageMakerTrainCard](../../../aws-q1-2022/Resource/MachineLearning/AmazonSageMakerTrainCard.Local.png) | ![illustration for AmazonSageMakerTrainGroup](../../../aws-q1-2022/Resource/MachineLearning/AmazonSageMakerTrainGroup.Local.png) |




## AmazonSageMakerTrain

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AmazonSageMakerTrain
include('aws-q1-2022/Resource/MachineLearning/AmazonSageMakerTrain')

' renders the element
AmazonSageMakerTrain('AmazonSageMakerTrain', 'Amazon Sage Maker Train', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AmazonSageMakerTrain
include('aws-q1-2022/Resource/MachineLearning/AmazonSageMakerTrain')

' renders the element
AmazonSageMakerTrain('AmazonSageMakerTrain', 'Amazon Sage Maker Train', 'an optional tech label', 'an optional description')
@enduml
```

## AmazonSageMakerTrainCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AmazonSageMakerTrainCard
include('aws-q1-2022/Resource/MachineLearning/AmazonSageMakerTrain')

' renders the element
AmazonSageMakerTrainCard('AmazonSageMakerTrainCard', 'Amazon Sage Maker Train Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AmazonSageMakerTrainCard
include('aws-q1-2022/Resource/MachineLearning/AmazonSageMakerTrain')

' renders the element
AmazonSageMakerTrainCard('AmazonSageMakerTrainCard', 'Amazon Sage Maker Train Card', 'an optional description')
@enduml
```

## AmazonSageMakerTrainGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AmazonSageMakerTrainGroup
include('aws-q1-2022/Resource/MachineLearning/AmazonSageMakerTrain')

' renders the element
AmazonSageMakerTrainGroup('AmazonSageMakerTrainGroup', 'Amazon Sage Maker Train Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AmazonSageMakerTrainGroup
include('aws-q1-2022/Resource/MachineLearning/AmazonSageMakerTrain')

' renders the element
AmazonSageMakerTrainGroup('AmazonSageMakerTrainGroup', 'Amazon Sage Maker Train Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
